==> nextcloud-app-spreed-1%3A19.0.8-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/es_AR.js <==
OC.L10N.register(
    "spreed",
    {
    "_%n guest_::_%n guests_" : ["%n inivitado","%n inivitados","%n inivitados"],
    "Talk" : "Hablar",
    "Guest" : "Invitado",
    "Message deleted by author" : "Mensaje eliminado por el autor",
    "File is too big" : "El archivo es demasiado grande.",
    "Invalid file provided" : "Archivo proporcionado inválido",
    "Invalid image" : "Imagen inválida",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Dismiss notification" : "Eliminar notificación",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Open settings" : "Abrir opciones",
    "error" : "error",
    "Messages" : "Mensajes",
    "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, favor de seguir el formato AAAA-MM-DD",
    "Leave call" : "Dejar la llamada",
    "Limit to groups" : "Limitar a grupos",
    "Everyone" : "Todos",
    "Save changes" : "Guardar cambios",
    "Saved!" : "¡Guardado!",
    "State" : "Estado",
    "Name" : "Nombre",
    "Description" : "Descripción",
    "Enabled" : "Habilitado",
    "Disabled" : "Deshabilitado",
    "Federation" : "Federación",
    "Beta" : "Beta",
    "Permissions" : "Permisos",
    "General settings" : "Configuraciones generales",
    "Off" : "Apagado",
    "Language" : "Idioma",
    "Country" : "País",
    "Status" : "Estatus",
    "Created at" : "Creado en",
    "Pending" : "Pendiente",
    "Error" : "Error",
    "Blocked" : "Bloqueado",
    "TURN server protocols" : "Protocolos del servidor TURN",
    "Failed" : "Error",
    "OK" : "OK",
    "Back" : "Atrás",
    "Cancel" : "Cancelar",
    "Confirm" : "Confirmar",
    "Reset" : "Restablecer",
    "Copy link" : "Copiar enlace",
    "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
    "Mute audio" : "Silenciar audio",
    "Disable video" : "Deshabilitar video",
    "You" : "Usted",
    "Collapse" : "Colapsar",
    "Favorite" : "Favorito",
    "Hide details" : "Ocultar detalles",
    "Show details" : "Mostrar detalles",
    "Disable" : "Deshabilitar",
    "Enable" : "Activar",
    "Choose" : "Elige",
    "Restricted" : "Restringido",
    "Personal" : "Personal",
    "Leave conversation" : "Dejar la conversación",
    "Delete conversation" : "Eliminar conversación",
    "Yes" : "Sí",
    "Password protection" : "Protección con contraseña",
    "Save" : "Guardar",
    "Edit" : "Editar",
    "More information" : "Más información",
    "Delete" : "Eliminar",
    "Log content" : "Contenido del registro",
    "User" : "Usuario",
    "Password" : "Contraseña",
    "API token" : "Ficha del API",
    "Login" : "Inicio de sesión",
    "Nickname" : "Apodo",
    "Client ID" : "ID del cliente",
    "Notifications" : "Notificaciones",
    "Remove from favorites" : "Eliminado de favoritos",
    "Add to favorites" : "Agregar a favoritos",
    "Users" : "Ususarios",
    "Groups" : "Grupos",
    "Loading" : "Cargando",
    "None" : "Ninguno",
    "Devices" : "Dispositivos",
    "Upload" : "Cargar",
    "Files" : "Archivos",
    "Reply" : "Responder",
    "Translate" : "Traducir",
    "Dismiss" : "Despedir",
    "Contact" : "Contacto",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
    "Close" : "Cerrar",
    "Password protect" : "Proteger con contraseña",
    "Send message" : "Enviar mensaje",
    "Group" : "Grupo",
    "New file" : "Nuevo archivo",
    "Settings" : "Ajustes",
    "Send" : "Enviar",
    "Remove" : "Eliminar",
    "Searching …" : "Buscando ...",
    "No results" : "Sin resultados",
    "Add users or groups" : "Agregar usuarios o grupos",
    "Participants" : "Participantes",
    "Chat" : "Chat",
    "Details" : "Detalles",
    "Privacy" : "Privacidad",
    "Keyboard shortcuts" : "Atajos de teclado",
    "Search" : "Buscar",
    "Show your screen" : "Mostrar su pantalla",
    "Stop screensharing" : "Dejar de compartir la pantalla",
    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir su pantalla. ",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Favor de usar un navegador diferente como Firefox o Chrome para compartir su pantalla.",
    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
    "Grid view" : "Vista de cuadrícula",
    "Submit" : "Enviar",
    "Media" : "Media",
    "Locations" : "Ubicaciones",
    "Audio" : "Audio",
    "Other" : "Otro",
    "Do not disturb" : "No molestar",
    "Away" : "Lejos",
    "Default" : "Predeterminado",
    "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
    "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
    "WebRTC is not supported in your browser" : "WebRTC no está soportado en su navegador",
    "Please use a different browser like Firefox or Chrome" : "Favor de usar un navegador diferente como Firefox o Chrome",
    "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
    "The password is wrong. Try again." : "Error en la contraseña. Inténtelo de nuevo.",
    "Android app" : "Aplicación android",
    "iOS app" : "Aplicación iOS",
    "Circles" : "Círculos",
    "Open sidebar" : "Abrir barra lateral",
    "Start a conversation" : "Iniciar una conversación",
    "TURN server" : "Servidor TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. "
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-spreed-1%3A21.1.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/es_AR.js <==
OC.L10N.register(
    "spreed",
    {
    "_%n guest_::_%n guests_" : ["%n inivitado","%n inivitados","%n inivitados"],
    "Talk" : "Hablar",
    "Guest" : "Invitado",
    "Message deleted by author" : "Mensaje eliminado por el autor",
    "Administration" : "Administración",
    "System" : "Sistema",
    "File is too big" : "El archivo es demasiado grande.",
    "Invalid file provided" : "Archivo proporcionado inválido",
    "Invalid image" : "Imagen inválida",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Description" : "Descripción",
    "Dismiss notification" : "Eliminar notificación",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "New message" : "Mensaje nuevo",
    "Open settings" : "Abrir opciones",
    "error" : "error",
    "Messages" : "Mensajes",
    "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
    "Federation" : "Federación",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, favor de seguir el formato AAAA-MM-DD",
    "Leave call" : "Dejar la llamada",
    "Everyone" : "Todos",
    "Save changes" : "Guardar cambios",
    "Saved!" : "¡Guardado!",
    "Limit to groups" : "Limitar a grupos",
    "Enabled" : "Habilitado",
    "Disabled" : "Deshabilitado",
    "State" : "Estado",
    "Name" : "Nombre",
    "Beta" : "Beta",
    "Permissions" : "Permisos",
    "Off" : "Apagado",
    "General settings" : "Configuraciones generales",
    "Enable encryption" : "Habilitar encripción",
    "Pending" : "Pendiente",
    "Error" : "Error",
    "Blocked" : "Bloqueado",
    "Language" : "Idioma",
    "Country" : "País",
    "Status" : "Estatus",
    "Created at" : "Creado en",
    "_%n user_::_%n users_" : ["%n usuario","%n usuarios","%n usuarios"],
    "TURN server protocols" : "Protocolos del servidor TURN",
    "Failed" : "Error",
    "OK" : "OK",
    "Confirm" : "Confirmar",
    "Reset" : "Restablecer",
    "Back" : "Atrás",
    "Cancel" : "Cancelar",
    "Calendar" : "Calendario",
    "Attendees" : "Asistentes",
    "Save" : "Guardar",
    "No results" : "Sin resultados",
    "Done" : "Terminado",
    "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
    "Copy link" : "Copiar enlace",
    "Mute audio" : "Silenciar audio",
    "Disable video" : "Deshabilitar video",
    "You" : "Usted",
    "Collapse" : "Colapsar",
    "Favorite" : "Favorito",
    "Note:" : "Nota:",
    "Hide details" : "Ocultar detalles",
    "Show details" : "Mostrar detalles",
    "Disable" : "Deshabilitar",
    "Enable" : "Activar",
    "Choose" : "Elige",
    "The file must be a PNG or JPG" : "El archivo debe ser PNG o JPG",
    "Restricted" : "Restringido",
    "Personal" : "Personal",
    "Leave conversation" : "Dejar la conversación",
    "Yes" : "Sí",
    "Delete conversation" : "Eliminar conversación",
    "Password protection" : "Protección con contraseña",
    "Set a password" : "Establecer una contraseña",
    "Edit" : "Editar",
    "More information" : "Más información",
    "Delete" : "Eliminar",
    "Log content" : "Contenido del registro",
    "Notifications" : "Notificaciones",
    "Log in" : "Iniciar sesión",
    "Remove from favorites" : "Eliminado de favoritos",
    "Add to favorites" : "Agregar a favoritos",
    "Users" : "Ususarios",
    "Groups" : "Grupos",
    "None" : "Ninguno",
    "Devices" : "Dispositivos",
    "Upload" : "Cargar",
    "Files" : "Archivos",
    "Reply" : "Responder",
    "Translate" : "Traducir",
    "Dismiss" : "Despedir",
    "Contact" : "Contacto",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
    "Send message" : "Enviar mensaje",
    "New file" : "Nuevo archivo",
    "Send" : "Enviar",
    "Settings" : "Ajustes",
    "Remove" : "Eliminar",
    "Add users or groups" : "Agregar usuarios o grupos",
    "Searching …" : "Buscando ...",
    "Participants" : "Participantes",
    "Chat" : "Chat",
    "Details" : "Detalles",
    "Load more results" : "Cargar más resultados",
    "Privacy" : "Privacidad",
    "Keyboard shortcuts" : "Atajos de teclado",
    "Search" : "Buscar",
    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir su pantalla. ",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Favor de usar un navegador diferente como Firefox o Chrome para compartir su pantalla.",
    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
    "Show your screen" : "Mostrar su pantalla",
    "Stop screensharing" : "Dejar de compartir la pantalla",
    "Grid view" : "Vista de cuadrícula",
    "Keep" : "Mantener",
    "Submit" : "Enviar",
    "User" : "Usuario",
    "Password" : "Contraseña",
    "API token" : "Ficha del API",
    "Login" : "Inicio de sesión",
    "Nickname" : "Apodo",
    "Client ID" : "ID del cliente",
    "Media" : "Media",
    "Locations" : "Ubicaciones",
    "Audio" : "Audio",
    "Other" : "Otro",
    "Group" : "Grupo",
    "Please reload the page." : "Favor de volver a cargar la página.",
    "Do not disturb" : "No molestar",
    "Away" : "Lejos",
    "Default" : "Predeterminado",
    "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
    "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
    "WebRTC is not supported in your browser" : "WebRTC no está soportado en su navegador",
    "Please use a different browser like Firefox or Chrome" : "Favor de usar un navegador diferente como Firefox o Chrome",
    "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
    "The password is wrong. Try again." : "Error en la contraseña. Inténtelo de nuevo.",
    "Android app" : "Aplicación android",
    "iOS app" : "Aplicación iOS",
    "__language_name__" : "Español (Argentina)",
    "Tasks" : "Tareas",
    "Notes" : "Notas",
    "Reports" : "Reportes",
    "Close" : "Cerrar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
